#!/bin/bash
#
# Simple script to create whole backup of an MSS instance.
# Belongs to mss-manager package.
#
# Usage: $0 existing_MSS_name [existing_MySQL_tablelist_file] as root user.

APACHEDOCROOT="/var/www"                                # Public web documentroot
DATETIME="`date '+%Y%m%d%H%M%S'`"			# Timestamp
MYSQL="/usr/bin/mysql --defaults-file=/etc/mysql/root.cnf"	# MySQL call as root
MYSQL_DUMPDB="/usr/local/sbin/mysql_dumpdb.sh"		# mysql_dumpdb script call
MYSQL_DUMPTBL="/usr/local/sbin/mysql_dumptbl.sh"	# mysql_dumptbl script call
MYSQL_SELECT_DOMAINS="SELECT hostname FROM t201_domain WHERE id_domainstate<>3 ORDER BY id_domain"
WSM="/usr/local/sbin/website-manager.sh"                # wsm script call

# Messages

MSG_MISSING="Missing file: "
MSG_NODOMAIN="No domains in "
MSG_USAGE="Usage: $0 existing_MSS_name [existing_MySQL_tablelist_file] as root user.\n\n"

# Including headers (if any)
HEADERS="/etc/default/mss-manager"
if [ -f "$HEADERS" ]; then . $HEADERS; fi

# Must be root!

if [ $UID -ne 0 ]; then echo -ne "$MSG_USAGE" >&2; exit $EXIT_ERR; fi

# Check components

if [ ! -x "$MYSQL_DUMPDB" ]; then echo -ne "$MSG_MISSING$MYSQL_DUMPDB.\n\n"  >&2; exit $EXIT_ERR; fi
if [ ! -x "$MYSQL_DUMPTBL" ]; then echo -ne "$MSG_MISSING$MYSQL_DUMPTBL.\n\n" >&2; exit $EXIT_ERR; fi
if [ ! -x "$WSM" ]; then echo -ne "$MSG_MISSING$WSM.\n\n" >&2; exit $EXIT_ERR; fi

# MSS instance is mandatory

CONTEXTROOT=$1; shift
if [ -z "$CONTEXTROOT" ]; then echo -ne "$MSG_USAGE" >&2; exit $EXIT_ERR; fi
if [ ! -d "$APACHEDOCROOT/$CONTEXTROOT" ]; then echo -ne "$MSG_USAGE" >&2; exit $EXIT_ERR; fi

# Database table list is optional, but must be valid

MYSQL_TABLELIST=$1; shift
echo "`dirname $0`/$MYSQL_TABLELIST"
if [ ! -z "$MYSQL_TABLELIST" ]; then
    if [ ! -f "$MYSQL_TABLELIST" ]; then echo -ne "$MSG_USAGE" >&2; exit $EXIT_ERR; fi
fi

# MySQL dump from table list (lack of them full dump)

if [ -f "$MYSQL_TABLELIST" ]; then
	backupfile="`pwd`/`hostname`.$CONTEXTROOT.$DATETIME.$CONTEXTROOT-`basename $MYSQL_TABLELIST`.sql.gz"
	$MYSQL_DUMPTBL -c $CONTEXTROOT $MYSQL_TABLELIST $backupfile
else
	backupfile="`pwd`/`hostname`.$CONTEXTROOT.$DATETIME.$CONTEXTROOT.sql.gz"
	$MYSQL_DUMPDB  -c $CONTEXTROOT $backupfile
fi

# Domains dump: whole MSS instance and domain-specific files via wsm

$WSM -sw $CONTEXTROOT
for domain in  $(echo "$MYSQL_SELECT_DOMAINS" | $MYSQL --skip-column-names -D $CONTEXTROOT)
do
    $WSM -sw $domain
done
